@@ -6,6 +6,8 @@ from typing import (
 
 from packaging import version
 
+import gidgethub.abc
+
 import abstracts
 
 import aiohttp
@@ -76,6 +78,18 @@ class IGithubAPI(metaclass=abstracts.Interface):
         """Return a `GithubRepository` for `k`"""
         raise NotImplementedError
 
+    @property  # type:ignore
+    @abstracts.interfacemethod
+    def api(self) -> Type[gidgethub.abc.GitHubAPI]:
+        """Github API."""
+        raise NotImplementedError
+
+    @property  # type:ignore
+    @abstracts.interfacemethod
+    def actions_class(self) -> Type["IGithubActions"]:
+        """Github actions class."""
+        raise NotImplementedError
+
     @property  # type:ignore
     @abstracts.interfacemethod
     def commit_class(self) -> Type["IGithubCommit"]:
@@ -142,6 +156,12 @@ class IGithubAPI(metaclass=abstracts.Interface):
         """Call the `gidgethub.post` api."""
         raise NotImplementedError
 
+    @property  # type:ignore
+    @abstracts.interfacemethod
+    def workflows_class(self) -> Type["IGithubWorkflows"]:
+        """Github workflows class."""
+        raise NotImplementedError
+
 
 class IGithubRepo(metaclass=abstracts.Interface):
 
@@ -149,6 +169,11 @@ class IGithubRepo(metaclass=abstracts.Interface):
     def __init__(self, github: "IGithubAPI", name: str) -> None:
         raise NotImplementedError
 
+    @property  # type:ignore
+    @abstracts.interfacemethod
+    def actions(self) -> "IGithubActions":
+        raise NotImplementedError
+
     @property  # type:ignore
     @abstracts.interfacemethod
     def github(self) -> IGithubAPI:
@@ -257,6 +282,36 @@ class IGithubIssue(metaclass=abstracts.Interface):
         raise NotImplementedError
 
 
+class IGithubActions(metaclass=abstracts.Interface):
+
+    @property  # type:ignore
+    @abstracts.interfacemethod
+    def github(self) -> IGithubAPI:
+        """Github API."""
+        raise NotImplementedError
+
+    @property  # type:ignore
+    @abstracts.interfacemethod
+    def repo(self) -> IGithubRepo:
+        """Github repo."""
+        raise NotImplementedError
+
+
+class IGithubWorkflows(metaclass=abstracts.Interface):
+
+    @property  # type:ignore
+    @abstracts.interfacemethod
+    def github(self) -> IGithubAPI:
+        """Github API."""
+        raise NotImplementedError
+
+    @property  # type:ignore
+    @abstracts.interfacemethod
+    def repo(self) -> IGithubRepo:
+        """Github repo."""
+        raise NotImplementedError
+
+
 class IGithubIssues(metaclass=abstracts.Interface):
 
     @abstracts.interfacemethod
